#version 110

#ifdef GL_ES
precision mediump float;
#endif

uniform vec3      iResolution;           // viewport resolution (in pixels)
uniform float     iDuration;             // shader playback total time (in seconds)
uniform float     iTime;                 // shader playback current time (in seconds)
uniform float     iTimeDelta;            // render time (in seconds)
uniform int       iFrame;                // shader playback frame
uniform float     iChannelTime[8];       // channel playback time (in seconds)
uniform vec3      iChannelResolution[8]; // channel resolution (in pixels)
uniform vec4      iMouse;                // mouse pixel coords. xy: current (if MLB down), zw: click
uniform sampler2D iChannel[8];           // input channel. XX = 2D/Cube
uniform vec4      iDate;                 // (year, month, day, time in seconds)
uniform float     iSampleRate;           // sound sample rate (i.e., 44100)

uniform float     strength;


float iProgress = iTime / iDuration;

const float PI = 3.141592653589793;

////////////////////////////////////////////////////////////////////////////////////////////////////////////

void mainImage( out vec4 fragColor, in vec2 fragCoord ) {
    vec2 uv = fragCoord / iResolution.xy;
    
    vec4 y = texture2D(iChannel[0], uv);
    vec4 y1 = texture2D(iChannel[0], uv);
    vec4 y2 = texture2D(iChannel[1], uv);
    
    vec2 centre = iResolution.xy / 2.0;
    float nT = 8.0;
    float t = iTime;
    float dl = length(iResolution);
    float l = dl / (1.5 * nT);
    float phi = t *  8.0 * PI;
    
    float mt = 1.0 - t / 100.0;
    float R = phi * l / (2.0 * PI);
    float R_sqrt = R * R + 0.5;
    
    if(R_sqrt < 0.0)
    {
       fragColor = vec4(1.0);
    }
    else
    {
    	float h_d = centre.y - (R + 0.5);
    	h_d = max(h_d, 0.0);
    	
    	float w_d = centre.x - (R + 0.5);
        w_d = max(w_d, 0.0);
        
        float tmp_1 = 255.0 * mt / R;
        float tmp_2 = 2.0 * PI / l;
        
   
        float r_sqrt = (centre.x - fragCoord.x) * (centre.x - fragCoord.x) + 
            (centre.y - fragCoord.y) * (centre.y - fragCoord.y);
            
        if(r_sqrt < R_sqrt)
        {
            float r = sqrt(r_sqrt);
            float tmpOffset = 20.0 * r * mt / R * cos(phi - tmp_2 * r);
                
            float u_alpha = tmp_1 * (1.0 - sin(phi - tmp_2 * r)) * r + 0.5;
            u_alpha = clamp(u_alpha, 0.0, 255.0);
			      float alpha = 255.0 - u_alpha;
                
            vec2 newpoint;				              
            newpoint.x = (fragCoord.x + tmpOffset) / iResolution.x;
            newpoint.y = (fragCoord.y + tmpOffset) / iResolution.y;                                 
                                                 
            vec4 point1 = texture2D(iChannel[0], newpoint) ;
            vec4 point2 = texture2D(iChannel[1], newpoint);  
            y = mix(point1,point2, alpha / 255.);
         }
            
        fragColor = y;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////

void main() {
    mainImage(gl_FragColor, gl_FragCoord.xy);
}
